@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use warnings;
 use strict;
@@ -63,7 +63,7 @@ sub _from_array {
         next unless $w; # TODO Skip zero weight nodes if requested?
 
         my $edge = Graph::Easy::Edge->new();
-        $edge->set_attributes({ "x-$attr" => $w });
+        $edge->set_attributes({ label => $w, "x-$attr" => $w });
 
         $self->add_edge($vertex, $n, $edge);
 
@@ -82,7 +82,7 @@ sub _from_hash {
         my $w = $neighbors->{$n}; # Weight of the edge to the neighbor.
 
         my $edge = Graph::Easy::Edge->new();
-        $edge->set_attributes({ "x-$attr" => $w });
+        $edge->set_attributes({ label => $w, "x-$attr" => $w });
 
         $self->add_edge($vertex, $n, $edge);
 
@@ -195,7 +195,7 @@ Graph::Easy::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
